From 7013a6693db029ae10d6d5711e0ef98713c51fd6 Mon Sep 17 00:00:00 2001
From: Olof-Joachim Frahm <olof@macrolet.net>
Date: Thu, 20 Mar 2014 20:55:22 +0100
Subject: [PATCH 1/3] Remove trailing whitespace, untabify.

---
 abcl/src/org/armedbear/lisp/abcl-contrib.lisp |   66 +++++++++++--------------
 1 file changed, 29 insertions(+), 37 deletions(-)

diff --git a/abcl/src/org/armedbear/lisp/abcl-contrib.lisp b/abcl/src/org/armedbear/lisp/abcl-contrib.lisp
index e5d515c..7c73943 100644
--- a/abcl/src/org/armedbear/lisp/abcl-contrib.lisp
+++ b/abcl/src/org/armedbear/lisp/abcl-contrib.lisp
@@ -2,10 +2,10 @@
 
 (require :asdf)
 
-(defconstant +get-classloader+ 
+(defconstant +get-classloader+
   (java:jmethod "java.lang.Class" "getClassLoader"))
 
-(defun boot-classloader () 
+(defun boot-classloader ()
   (let ((boot-class (java:jclass "org.armedbear.lisp.Main")))
     (java:jcall +get-classloader+ boot-class)))
 
@@ -18,35 +18,35 @@ (defun contrib-jar-p (p)
 (defun named-jar-p (name p)
   (and (pathnamep p)
        (equal (pathname-type p) "jar")
-       (or 
+       (or
         (java:jstatic "matches"
-                      "java.util.regex.Pattern" 
+                      "java.util.regex.Pattern"
                       (concatenate 'string name "(-[0-9]\\.[0-9]\\.[0-9]([+~-].+)?)?")
                       (pathname-name p))
         (java:jstatic "matches"
-                      "java.util.regex.Pattern" 
+                      "java.util.regex.Pattern"
                       (concatenate 'string name "(-[0-9]\\.[0-9]\\.[0-9]\\.[0-9]([+~-]+)?)?")
                       (pathname-name p)))
        (make-pathname :defaults p :name name)))
 
 (defun find-system ()
-  "Find the location of the system.  
+  "Find the location of the system.
 
 Used to determine relative pathname to find 'abcl-contrib.jar'."
-  (or 
-   (ignore-errors 
+  (or
+   (ignore-errors
      (find-system-jar))
    (ignore-errors
-     (some 
-      (lambda (u) 
-        (probe-file (make-pathname 
-                     :defaults  (java:jcall "toString" u)
+     (some
+      (lambda (u)
+        (probe-file (make-pathname
+                     :defaults (java:jcall "toString" u)
                      :name "abcl")))
       (java:jcall "getURLs" (boot-classloader))))
-   (ignore-errors 
+   (ignore-errors
      #p"http://abcl.org/releases/current/abcl.jar")))
 
-(defun find-system-jar () 
+(defun find-system-jar ()
   "Return the pathname of the system jar, one of `abcl.jar` or `abcl-m.n.p.jar` or `abcl-m.n.p[.~-]something.jar`."
     (dolist (loader (java:dump-classpath))
       (let ((abcl-jar (some #'system-jar-p loader)))
@@ -79,7 +79,7 @@ (defun find-and-add-contrib (&key (verbose nil))
   (if *abcl-contrib*
       (format verbose "~&Using already initialized value of abcl-contrib:~&'~A'.~%"
               *abcl-contrib*)
-      (progn 
+      (progn
         (setf *abcl-contrib* (find-contrib))
         (format verbose "~&Using probed value of abcl-contrib:~&'~A'.~%"
                 *abcl-contrib*)))
@@ -87,29 +87,21 @@ (defun find-and-add-contrib (&key (verbose nil))
 
 (defun find-contrib ()
   "Introspect runtime classpaths to find a loadable ABCL-CONTRIB."
-  (or (ignore-errors 
-		(when (find-system-jar)
-		  (probe-file 
-		   (make-pathname :defaults (find-system-jar)
-						  :name "abcl-contrib"))))
-	  (some 
-	   (lambda (u) 
-		 (probe-file (make-pathname 
-					  :defaults  (java:jcall "toString" u)
-					  :name "abcl-contrib")))
-	   (java:jcall "getURLs" (boot-classloader)))))
-
-(export `(find-system 
+  (or (ignore-errors
+                (when (find-system-jar)
+                  (probe-file
+                   (make-pathname :defaults (find-system-jar)
+                                                  :name "abcl-contrib"))))
+          (some
+           (lambda (u)
+                 (probe-file (make-pathname
+                                          :defaults (java:jcall "toString" u)
+                                          :name "abcl-contrib")))
+           (java:jcall "getURLs" (boot-classloader)))))
+
+(export `(find-system
           find-contrib
           *abcl-contrib*))
+
 (when (find-and-add-contrib :verbose t)
   (provide :abcl-contrib))
-
-
-
-
-
-
-
-           
-  
-- 
1.7.10.4

